// Copyright (c) 2008, NTT DATA Corporation.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using Microsoft.VisualStudio.TestTools.UnitTesting;
using System;
using System.Text;
using System.Collections.Generic;
using TERASOLUNA.Fw.Common.Validation;
using TERASOLUNA.Fw.Client;
using TERASOLUNA.Fw.Common.Logging;
using TERASOLUNA.Fw.Utlib.Logging;
namespace TERASOLUNA.Fw.ClientUT
{
    /// <summary>
    ///TERASOLUNA.Fw.Client.CustomValidatingEventArgs のテスト クラスです。すべての
    ///TERASOLUNA.Fw.Client.CustomValidatingEventArgs 単体テストをここに含めます
    ///</summary>
    [TestClass()]
    public class CustomValidatingEventArgsTest
    {


        private TestContext testContextInstance;

        /// <summary>
        ///現在のテストの実行についての情報および機能を
        ///提供するテスト コンテキストを取得または設定します。
        ///</summary>
        public TestContext TestContext
        {
            get
            {
                return testContextInstance;
            }
            set
            {
                testContextInstance = value;
            }
        }
        #region 追加のテスト属性
        // 
        //テストを作成するときに、次の追加属性を使用することができます:
        //
        //クラスの最初のテストを実行する前にコードを実行するには、ClassInitialize を使用
        //
        //[ClassInitialize()]
        //public static void MyClassInitialize(TestContext testContext)
        //{
        //}
        //
        //クラスのすべてのテストを実行した後にコードを実行するには、ClassCleanup を使用
        //
        //[ClassCleanup()]
        //public static void MyClassCleanup()
        //{
        //}
        //
        //各テストを実行する前にコードを実行するには、TestInitialize を使用
        [TestInitialize()]
        public void MyTestInitialize()
        {
            LogUTUtil.Clear();
        }
        //
        //各テストを実行した後にコードを実行するには、TestCleanup を使用
        //
        //[TestCleanup()]
        //public void MyTestCleanup()
        //{
        //}
        //
        #endregion

        /// <summary>
        ///CustomValidatingEventArgs (ValidationResult) のテスト
        ///</summary>
        /// <remarks>
        /// コンストラクタで値が正常に設定されていることを確認するテスト。
        /// </remarks>
        [TestMethod()]
        public void ConstructorTest()
        {
            // 準備
            ValidationResult expectedValidationResult = new ValidationResult();

            // 実施
            CustomValidatingEventArgs target = new CustomValidatingEventArgs(expectedValidationResult);

            // 確認
            TERASOLUNA_Fw_Client_CustomValidatingEventArgsAccessor accessor = new TERASOLUNA_Fw_Client_CustomValidatingEventArgsAccessor(target);
            Assert.AreSame(expectedValidationResult, accessor._validationResult);

            // ログ
            Assert.AreEqual(0, LogUTUtil.CountLogs(typeof(CustomValidatingEventArgs), LogLevel.INFO));
        }

        /// <summary>
        ///ValidationResult のテスト
        ///</summary>
        /// <remarks>
        /// 想定通りの値の取得ができることを確認するテスト。
        /// </remarks>
        [TestMethod()]
        public void ValidationResultTest()
        {
            // 準備
            CustomValidatingEventArgs target = new CustomValidatingEventArgs(null);
            ValidationResult expectedValidationResult = new ValidationResult();
            TERASOLUNA_Fw_Client_CustomValidatingEventArgsAccessor accessor = new TERASOLUNA_Fw_Client_CustomValidatingEventArgsAccessor(target);
            accessor._validationResult = expectedValidationResult;

            // 実施
            ValidationResult actualValidationResult = target.ValidationResult;

            // 確認
            Assert.AreSame(expectedValidationResult, actualValidationResult);

            // ログ
            Assert.AreEqual(0, LogUTUtil.CountLogs(typeof(CustomValidatingEventArgs), LogLevel.INFO));
        }

    }
}
